@@ -6,7 +6,7 @@
 #include <unistd.h>
 #endif
 #define WAIT_TIME 5
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
