@@ -1,7 +1,7 @@
 #include <stdio.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   int port=5051;
   MCAgency_t agency;
