@@ -4,7 +4,7 @@
 #include <windows.h>
 #endif
 #define WAIT_TIME 2
-int main(int argc, char *argv[]) 
+int main() 
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
