@@ -1,8 +1,10 @@
+/* File: agent_saved_variables_example/client.c */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
