@@ -5,7 +5,7 @@
 #endif
 
 #define WAIT_TIME 5
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
