@@ -7,7 +7,7 @@
 #endif
 #define COND_ID 55
 
-int main(int argc, char *argv[])
+int main()
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
