@@ -5,7 +5,7 @@
 #else
 #include <unistd.h>
 #endif
-int main(int argc, char *argv[])
+int main()
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
