@@ -6,7 +6,7 @@
 #include <unistd.h>
 #endif
 #define MUTEX_ID 55
-int main(int argc, char *argv[])
+int main()
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
