@@ -1,8 +1,10 @@
+/* File: hello_world/client.c */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
@@ -10,7 +12,7 @@ int main(int argc, char *argv[])
   int remote_port = 5051;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+//  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
   agency = MC_Initialize(port, &options);
 
   /* Note: The third argument of the following function may also be a
@@ -19,6 +21,7 @@ int main(int argc, char *argv[])
       "test1.xml",
       "localhost",
       remote_port);
+  MC_MainLoop(agency);
   MC_End(agency);
   exit(0);
 }
