@@ -3,7 +3,7 @@
 #include <libmc.h>
 #include <string.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
