@@ -16,7 +16,7 @@
 #include <unistd.h>
 #endif
 
-int main(int argc, char *argv[])
+int main()
 {
   MCAgency_t agency;
   MCAgent_t agent;
