@@ -2,7 +2,7 @@
 #include <stdlib.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgent_t agent;
@@ -44,7 +44,11 @@ int main(int argc, char *argv[])
   */
 
   MC_AddAgent(agency,agent);
-  sleep(10);
+#ifndef _WIN32
+  sleep(5);
+#else
+  Sleep(5000);
+#endif
 
   agent = MC_ComposeAgentFromFile(
     "MobileAgent1",
@@ -56,7 +60,11 @@ int main(int argc, char *argv[])
     0);
   MC_AddAgent(agency,agent);
 
-  sleep(10);
+#ifndef _WIN32
+  sleep(5);
+#else
+  Sleep(5000);
+#endif
 
   /* Note: The third argument of the following function may also be a
      valid IP address in the form of a string. i.e. 192.168.0.1 */
