@@ -16,7 +16,7 @@
 #include <unistd.h>
 #endif
 
-int main(int argc, char *argv[])
+int main()
 {
     /* Init the agency */
     MCAgency_t agency;
