@@ -2,7 +2,7 @@
 #include <stdlib.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgent_t agent;
