@@ -1,5 +1,6 @@
 #include <libmc.h>
 #include <string.h>
+#include <embedch.h>
 int main() {
     MCAgency_t agency;
     int local_port = 5130;
@@ -10,14 +11,22 @@ int main() {
      * "C:/Ch/toolkit/embedch" for testing purposes.                 *
      *****************************************************************/
     char embedchhome[] = "C:/Ch/toolkit/embedch";
-    ChOptions_t ch_options;
+    ChOptions_t* ch_options;
 
-    ch_options.shelltype = CH_REGULARCH;
-    ch_options.chhome = malloc(strlen(embedchhome)+1);
-    strcpy(ch_options.chhome, embedchhome);
+    MCAgencyOptions_t mc_options;
 
-    agency = MC_Initialize(local_port, NULL);
-    MC_ChInitializeOptions(agency, &ch_options);
+    MC_InitializeAgencyOptions(&mc_options);
+
+    ch_options = (ChOptions_t*)malloc(sizeof(ChOptions_t));
+
+    ch_options->shelltype = CH_REGULARCH;
+    ch_options->chhome = malloc(strlen(embedchhome)+1);
+    strcpy(ch_options->chhome, embedchhome);
+
+    mc_options.ch_options = ch_options;
+
+
+    agency = MC_Initialize(local_port, &mc_options);
 
     if(MC_MainLoop(agency) != 0) {
         MC_End(agency);
