@@ -3,7 +3,7 @@
 #include <libmc.h>
 #define TotalMA 2
 
-int main(int argc, char *argv[])
+int main()
 {
   MCAgency_t agency;
   MCAgent_t agent;
