@@ -1,7 +1,9 @@
+/* File: multi_task_example/client.c */
+
 #include <stdio.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
