@@ -7,7 +7,7 @@
 #include <windows.h>
 #endif
 
-int main(int argc, char *argv[])
+int main()
 {
   /* Init the agency */
   MCAgency_t agency;
