@@ -2,7 +2,7 @@
 #include <embedch.h>
 #include <stdio.h>
 
-int main(int argc, char *argv[])
+int main()
 {
   MCAgency_t agency;
   MCAgent_t agent;
