@@ -1,7 +1,7 @@
 #include <stdio.h>
 #include <libmc.h>
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   int local_port = 5051;
