@@ -24,7 +24,7 @@ void* stationary_agent_func(struct agent_thread_arg_s* agent_thread_arg)
 	return NULL;
 }
 
-int main(int argc, char *argv[]) 
+int main() 
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
