@@ -1,7 +1,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <libmc.h>
-int main(int argc, char *argv[])
+int main()
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
