@@ -8,7 +8,7 @@
 #include <libmc.h>
 #include <stdio.h>
 
-int main(int argc, char *argv[])
+int main()
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
