@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 457 $ : Last Committed Revision
- * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
+ * $Revision: 466 $ : Last Committed Revision
+ * $Date: 2010-05-16 21:07:38 -0700 (Sun, 16 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -176,10 +176,10 @@ cmd_prompt_Thread( LPVOID arg )
     mc_platform_p mc_platform = (mc_platform_p)arg;
     cmd.index = COMMAND_COUNT;
     printf("\n");
-	buf = (char*)malloc(sizeof(char) * 100);
-	if (!buf) {fprintf(stderr, "Malloc failed at %s:%d.\n", __FILE__, __LINE__); }
+    buf = (char*)malloc(sizeof(char) * 100);
+    if (!buf) {fprintf(stderr, "Malloc failed at %s:%d.\n", __FILE__, __LINE__); }
 #ifdef HAVE_LIBREADLINE
-  initialize_readline();
+    initialize_readline();
 #endif
     while(1)
     {
@@ -187,23 +187,25 @@ cmd_prompt_Thread( LPVOID arg )
 #ifdef HAVE_LIBREADLINE
         buf = readline("MobileC > ");
         if (*buf) {
-          add_history(buf);
+            add_history(buf);
         }
 #else
-		printf("MobileC > ");
+        printf("MobileC > ");
 #ifndef _WIN32
-		if (!fgets(buf, 100, stdin)) 
+        if (!fgets(buf, 100, stdin)) 
 #else
-		if (!gets(buf))  /* FIXME, for the love of god FIXME */
+            if (!gets(buf))  /* FIXME, for the love of god FIXME */
 #endif
-		{
-			fprintf(stderr, "fgets failed at %s:%d\n", __FILE__, __LINE__);
-		}
+            {
+                fprintf(stderr, "fgets failed at %s:%d\n", __FILE__, __LINE__);
+            }
 #endif
         /* Get rid of newline character */
-        if (buf[strlen(buf)-1] == '\n') 
-        {
-            buf[strlen(buf)-1] = '\0';
+        if(strlen(buf) > 0) {
+            if (buf[strlen(buf)-1] == '\n') 
+            {
+                buf[strlen(buf)-1] = '\0';
+            }
         }
         cmd.num_args = split_string(&cmd.args, buf);
         process_command(&cmd);
@@ -404,3 +406,33 @@ int handler_FLUSH_AGENTS(void *arg, mc_platform_p global) /*{{{*/
     return 0;
 } /*}}}*/
 
+int handler_COMPOSE_SEND(void *arg, mc_platform_p global)
+{
+    /* args: filename, hostname, port */
+    command_t* cmd = (command_t*)arg;
+    MCAgent_t agent;
+    char name[80];
+    char server[200];
+    if(cmd->num_args != 4) 
+    {
+        printf("%s\n", command_descriptions[COMMAND_COMPOSE_SEND]);
+        return 0;
+    }
+    sprintf(name, "agent%d", rand()%1000);
+    sprintf(server, "%s:%s", cmd->args[2], cmd->args[3]);
+    agent = MC_ComposeAgentFromFile(
+      name,
+      global->hostname,
+      name,
+      cmd->args[1],
+      NULL,
+      server,
+      0
+      );
+    if (agent != NULL) {
+      MC_AddAgent(global->agency, agent);
+      return 0;
+    } else {
+      return -1;
+    }
+}
