@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 457 $ : Last Committed Revision
- * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
+ * $Revision: 458 $ : Last Committed Revision
+ * $Date: 2010-05-14 13:33:23 -0700 (Fri, 14 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -59,3 +59,8 @@ COMMAND(FLUSH_AGENTS,
         "flush_agents",
         "This command flushes all of the agents on the system which are still\n\
         on the agent list.\n")
+COMMAND(COMPOSE_SEND, "compose_send",
+        "This command composes an agent from Ch source code and sends \n \
+        it to a remote host. Usage is: \n \
+        \"compose_send <filename> <target host> <target port>\"\n \
+        e.g. \"compose_send agent_code.c iel.ucdavis.edu 5050\"")
