@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 457 $ : Last Committed Revision
- * $Date: 2010-05-12 15:45:11 -0700 (Wed, 12 May 2010) $ : Last Committed Date */
+ * $Revision: 468 $ : Last Committed Revision
+ * $Date: 2010-05-17 12:52:54 -0700 (Mon, 17 May 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -700,7 +700,7 @@ MC_ComposeAgentS(
 			fprintf(stderr, "Memory Error %s:%d\n", __FILE__, __LINE__);
 		}
 	}
-  
+ 
   return agent;
 }
 
@@ -743,7 +743,10 @@ EXPORTMC MCAgent_t MC_ComposeAgentFromFileS(
   int codesize;
   FILE* fptr;
 
-  stat(filename, &buffer);
+  if(stat(filename, &buffer)) {
+    /* Stat failed. Maybe file does not exist? */
+    return NULL;
+  }
   codesize = buffer.st_size;
   code = (char *)malloc((codesize+1)*sizeof(char));
   memset(code, 0, codesize+1);
@@ -1240,10 +1243,7 @@ MC_Initialize( /*{{{*/
   if (ret->hostName == NULL) {return NULL;}
   gethostname(ret->hostName, HOST_NAME_MAX);
   /*Save some memory */
-  CHECK_NULL(
-      realloc(ret->hostName, sizeof(char)*(strlen(ret->hostName)+1)),
-      return NULL;
-      );
+  ret->hostName = realloc(ret->hostName, sizeof(char)*(strlen(ret->hostName)+1));
   if (ret->hostName == NULL) {return NULL;}
   ret->portno = port;
   ret->server = 1;
@@ -1997,15 +1997,6 @@ MC_TerminateAgentWG(MCAgent_t calling_agent, MCAgent_t agent) /*{{{*/
   return status;
 } /*}}}*/
 
-#ifdef _WIN32
-EXPORTMC BOOL
-MC_MainLoop(MCAgency_t attr) /*{{{*/
-{
-  /*    return CloseHandle(attr->global->gaf_ap->thread_id[attr->global->mr_index]); */
-  Sleep (INFINITE);
-  return 0;
-}
-#else
 int 
 MC_MainLoop(MCAgency_t attr) 
 {
@@ -2016,7 +2007,6 @@ MC_MainLoop(MCAgency_t attr)
   MUTEX_UNLOCK( attr->mc_platform->quit_lock );
   return 0;
 } /*}}}*/
-#endif
 
 EXPORTMC int
 MC_WaitAgent(MCAgency_t attr) /*{{{*/
